@@ -145,9 +145,9 @@ $_gmsg['l_allowdirectaccess'] = 'Allow Direct Access';
 $_gmsg['l_allowedRobotHits'] = 'Allowed Robot Hits';
 $_gmsg['l_allowedhosts'] = 'Allowed Domains';
 $_gmsg['l_allowoverride'] = 'Allow Override';
-$_gmsg['l_allowquic'] = 'Allow QUIC';
 $_gmsg['l_allowsetuid'] = 'Allow Set UID';
 $_gmsg['l_allowsymbollink'] = 'Follow Symbolic Link';
+$_gmsg['l_alpn'] = 'ALPN';
 $_gmsg['l_apachebinpath'] = 'Apache Binary Path';
 $_gmsg['l_apacheconf'] = 'Apache Style configurations';
 $_gmsg['l_apacheconffile'] = 'Apache Configuration File';
@@ -256,17 +256,17 @@ $_gmsg['l_enabledyngzipcompress'] = 'Enable GZIP Dynamic Compression';
 $_gmsg['l_enableecdhe'] = 'Enable ECDH Key Exchange';
 $_gmsg['l_enableexpires'] = 'Enable Expires';
 $_gmsg['l_enablegzip'] = 'Enable GZIP Compression';
+$_gmsg['l_enablebrotli'] = 'Enable Brotli Compression';
 $_gmsg['l_enableh2c'] = 'Enable HTTP/2 Over Cleartext TCP';
 $_gmsg['l_enablehooks'] = 'Enable Module';
 $_gmsg['l_enablehotlinkctrl'] = 'Enable Hotlink Protection';
 $_gmsg['l_enableipgeo'] = 'Enable GeoLocation Lookup';
 $_gmsg['l_enablelve'] = 'Cloud Linux';
 $_gmsg['l_enableprivatecache'] = 'Enable Private Cache';
-$_gmsg['l_enablequic'] = 'Enable QUIC';
+$_gmsg['l_enablequic'] = 'Enable HTTP3/QUIC';
 $_gmsg['l_enablerailshosting'] = 'Enable Shared Hosting';
 $_gmsg['l_enablerewrite'] = 'Enable Rewrite';
 $_gmsg['l_enablescript'] = 'Enable Scripts/ExtApps';
-$_gmsg['l_enablespdy'] = 'Enable SPDY/HTTP2/HTTP3';
 $_gmsg['l_enablestapling'] = 'Enable OCSP Stapling';
 $_gmsg['l_enablestderrlog'] = 'Enable stderr Log';
 $_gmsg['l_env'] = 'Environment';
@@ -402,6 +402,7 @@ $_gmsg['l_ocspresponder'] = 'OCSP Responder';
 $_gmsg['l_ocspstapling'] = 'OCSP Stapling';
 $_gmsg['l_oldpass'] = 'Old Password';
 $_gmsg['l_onlyself'] = 'Only Self Reference';
+$_gmsg['l_openudpport'] = 'Open HTTP3/QUIC (UDP) Port';
 $_gmsg['l_order'] = 'Order';
 $_gmsg['l_outbandwidth'] = 'Outbound Bandwidth (bytes/sec)';
 $_gmsg['l_pass'] = 'Password';
@@ -421,7 +422,7 @@ $_gmsg['l_process'] = 'Process';
 $_gmsg['l_prochardlimit'] = 'Process Hard Limit';
 $_gmsg['l_procsoftlimit'] = 'Process Soft Limit';
 $_gmsg['l_protocolver'] = 'Protocol Version';
-$_gmsg['l_quic'] = 'QUIC';
+$_gmsg['l_quic'] = 'HTTP3/QUIC';
 $_gmsg['l_quicbaseplpmtu'] = 'PLPMTU Base Value';
 $_gmsg['l_quiccfcw'] = 'Connection Flow Control Window';
 $_gmsg['l_quicenabledplpmtud'] = 'Enable DPLPMTUD';
@@ -433,7 +434,7 @@ $_gmsg['l_quicmaxsfcw'] = 'Max Stream Flow Control Window';
 $_gmsg['l_quicmaxstreams'] = 'Max Concurrent Streams Per Connection';
 $_gmsg['l_quicsfcw'] = 'Stream Flow Control Window';
 $_gmsg['l_quicshmdir'] = 'QUIC SHM Directory';
-$_gmsg['l_quicversions'] = 'QUIC Versions';
+$_gmsg['l_quicversions'] = 'HTTP3/QUIC Versions';
 $_gmsg['l_railsapplimit'] = 'Max Apps per Account';
 $_gmsg['l_railshosting'] = 'Rack/Rails Shared Hosting';
 $_gmsg['l_railssettings'] = 'Rack/Rails Default Settings';
